@@ -160,8 +160,7 @@ class FileDownloader(object):
             log.debug('Block size: %s' % self.block_size)
 
     def _write_to_file(self):
-        """Writes download data to disk
-        """
+        """Writes download data to disk"""
         # Writes file to disk
         # TODO: Maybe add more verification here
         # Suggestions always welcome
